@@ -26,7 +26,10 @@ class BackgroundChecker;
 
 class KateOnTheFlyChecker : public QObject, private KTextEditor::MovingRangeFeedback
 {
-    enum ModificationType { TEXT_INSERTED = 0, TEXT_REMOVED };
+    enum ModificationType {
+        TEXT_INSERTED = 0,
+        TEXT_REMOVED
+    };
 
     typedef QPair<KTextEditor::MovingRange *, QString> SpellCheckItem;
     typedef QList<KTextEditor::MovingRange *> MovingRangeList;
@@ -53,7 +56,7 @@ public:
     void updateConfig();
     void refreshSpellCheck(KTextEditor::Range range = KTextEditor::Range::invalid());
 
-    void updateInstalledMovingRanges(KTextEditor::ViewPrivate *view);
+    void updateInstalledMovingRanges(KTextEditor::View *view);
 
 protected:
     KTextEditor::DocumentPrivate *const m_document;
@@ -80,7 +83,7 @@ protected:
     void addToSpellCheckQueue(KTextEditor::MovingRange *range, const QString &dictionary);
 
     QTimer *m_viewRefreshTimer;
-    QPointer<KTextEditor::ViewPrivate> m_refreshView;
+    QPointer<KTextEditor::View> m_refreshView;
 
     virtual void removeRangeFromEverything(KTextEditor::MovingRange *range);
     bool removeRangeFromCurrentSpellCheck(KTextEditor::MovingRange *range);
@@ -108,7 +111,7 @@ protected:
     void addView(KTextEditor::Document *document, KTextEditor::View *view);
     void removeView(KTextEditor::View *view);
 
-    void restartViewRefreshTimer(KTextEditor::ViewPrivate *view);
+    void restartViewRefreshTimer(KTextEditor::View *view);
     void viewRefreshTimeout();
 
     void handleModifiedRanges();
